pub struct MissRun {
pub start: u32,
pub len: u32,
}Expand description
A contiguous run of expert ids, [start, start + len).
Misses are coalesced into runs because one transfer entry per run is
one descriptor and one large copy, where one entry per expert is
num_experts descriptors of one row each – the same bytes at a
fraction of the achievable rate, and enough small entries to trip
the SMALL_BANK_FEAT_BYTES floor.
Fields
start: u32len: u32Trait Implementations
impl Copy for MissRun
impl Eq for MissRun
impl StructuralPartialEq for MissRun