pub struct LoraStack { /* private fields */ }Expand description
Every adapter attached to one base matrix, applied in order. Two
adapters on one weight are two terms of the sum, as they are in
llama.cpp’s for (const auto & lora : *loras).
Implementations
Sourceimpl LoraStack
impl LoraStack
pub fn new(delta: LoraDelta) -> Self
pub fn push(&mut self, delta: LoraDelta)
pub fn len(&self) -> usize
pub fn is_empty(&self) -> bool
pub fn deltas(&self) -> &[LoraDelta]
pub fn resident_bytes(&self) -> usize
Sourcepub fn add_row_to(&self, r: usize, out_row: &mut [f32])
pub fn add_row_to(&self, r: usize, out_row: &mut [f32])
The delta of one row, for a row gather.
Sourcepub fn add_batch_to(&self, x_batch: &[f32], batch: usize, out: &mut [f32])
pub fn add_batch_to(&self, x_batch: &[f32], batch: usize, out: &mut [f32])
out[b] += Σ_i s_i · B_i (A_i x_b) over a [batch][cols] input.